pub struct FileSystemTree { /* private fields */ }Available on crate features
collateral_manager and fs_collateral_tree only.Expand description
Provides access to a collateral tree stored in the file system.
The directories in the collateral tree must follow this structure:
PRODUCT/VARIANT/STEPPING/SECURITY/crashlog/ITEM_PATH
A CollateralManager that uses a collateral tree stored in the file system can be created
using the CollateralManager::file_system_tree function.