CollateralTree

Trait CollateralTree 

pub trait CollateralTree {
    // Required methods
    fn get(&self, pvss: &PVSS, path: &ItemPath) -> Result<Vec<u8>, Error>;
    fn search(&self, path: &ItemPath) -> Result<Vec<PVSS>, Error>;
}
A trait representing a data structure that provides a direct access to the product-specific collateral files.

Required Methods

fn get(&self, pvss: &PVSS, path: &ItemPath) -> Result<Vec<u8>, Error>

Returns the content of an item in the collateral tree.

fn search(&self, path: &ItemPath) -> Result<Vec<PVSS>, Error>

Returns a list of all the PVSS that have an item defined at the given path.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors