CollateralTree

Trait CollateralTree 

pub trait CollateralTree {
    // Required methods
    fn get(&self, pvss: &PVSS, path: &ItemPath) -> Result<Vec<u8>, Error>;
    fn search(&self, path: &ItemPath) -> Result<Vec<PVSS>, Error>;
}
Available on crate feature collateral_manager only.
A trait representing a data structure that provides a direct access to the product-specific collateral files.

Required Methods

fn get(&self, pvss: &PVSS, path: &ItemPath) -> Result<Vec<u8>, Error>

Returns the content of an item in the collateral tree.

fn search(&self, path: &ItemPath) -> Result<Vec<PVSS>, Error>

Returns a list of all the PVSS that have an item defined at the given path.

Implementors

Source

impl CollateralTree for EmbeddedTree

Available on crate feature embedded_collateral_tree only.
Source

impl CollateralTree for FileSystemTree

Available on crate feature fs_collateral_tree only.